import { server } from '../../lib/server';
import { Static, Type } from '@sinclair/typebox';
import { prisma } from '../../lib/db';
import { ForbiddenError } from '../../lib/http-errors';

const FightStartInput = Type.Object({
  params: Type.Object({
    playerId: Type.String(),
    fightId: Type.String()
  })
});

type FightStartInputType = Static<typeof FightStartInput>;

export type FightStartType = {
  id: String
}

export const startFight = server.post<FightStartInputType, FightStartType>('/v1/accounts/:playerId/fight/:fightId', {
  schema: FightStartInput,
  authenicated: true
}, async req => {
  
  const { playerId } = req.params;


  const res = await prisma.fight.update({
    where: {
      id: req.params.fightId
    },
    data: {
      playerId: playerId
    }
  });

  if(!res) {
    throw new ForbiddenError('You can not start a fight with a monster that does not exist');
  }

  return {
    id: res.id
  }
});
